#lang swindle

;Always the first step: load the VIGRA PLT Lib
(require vigraplt/vigraplt)


(display "loading blox-image")(newline)
 (define img (loadimage  (build-path vigraplt-path "blox.gif")))

(display "performance test gaussian smoothing")(newline)
(display "vigra-method [in ms]:")(newline)
(time (gsmooth img 0.3))


(display "performing watershed transform on resized gradient image")(newline)
 (define  img2 (regionimagetocrackedgeimage
                (labelimage
                 (watersheds
                  (ggradient 
                   (resizeimage img (* 2 (image-width img))(* 2 (image-height img)) 5)
                   1.0)))
                0.0))

(display "performing fft on image")(newline)
(define  img3 (fouriertransform (loadimage (build-path vigraplt-path "rect.gif"))))
(define  img3magnitude (image-map (lambda (real imag) (sqrt (+ (* real real) (* imag imag)))) (car img3) (cdr img3)))  

(display "testing rotation and reflection functions on image")(newline)
(define  img4 (reflectimage img 3))
(define  img5 (rotateimage img 15.0 3))


(display "testing affine transformation on image")(newline)
(define theta (/(* 15 3.14157) 180))

(define rotmat (make-matrix 3 3 0.0))
(matrix-set! rotmat 0 0 (cos theta))
(matrix-set! rotmat 1 1 (cos theta))
(matrix-set! rotmat 0 1 (* -1 (sin theta)))
(matrix-set! rotmat 1 0 (sin theta))
(matrix-set! rotmat 2 2 1.0)

(define t1mat (make-matrix 3 3 0.0))
(matrix-set! t1mat 0 0 1.0)
(matrix-set! t1mat 1 1 1.0)
(matrix-set! t1mat 2 2 1.0)
(matrix-set! t1mat 0 2 (/ (image-width img) -2.0))
(matrix-set! t1mat 1 2 (/ (image-width img) -2.0))

(define t2mat (make-matrix 3 3 0.0))
(matrix-set! t2mat 0 0 1.0)
(matrix-set! t2mat 1 1 1.0)
(matrix-set! t2mat 2 2 1.0)
(matrix-set! t2mat 0 2 (/ (image-width img) 2.0))
(matrix-set! t2mat 1 2 (/ (image-width img) 2.0))



(define  img6 (affinewarpimage img (matrix-mult t1mat (matrix-mult rotmat t2mat)) 3))



(display "performing distance transform on canny edges of image")(newline)
 (define  img7 (distancetransform
		  (cannyedgeimage img 1.8 0.1 100.0)
		  0.0 2))

(display "testing difference of exponential edge detection on image")(newline)
(define  img8 (differenceofexponentialedgeimage img 1.8 0.5 100.0))

(display "testing nearly all filters")(newline)
(define  img9 (gsmooth img 3.0))
(define  img10 (laplacianofgaussian img 3.0))
(define  img11 (gsharpening img 0.5 3.0))
(define  img12 (sharpening img 3.0))
(define  img13 (nonlineardiffusion img 0.1 2.0))

(display "saving resulting images")(newline)
(saveimage img2   (build-path vigraplt-path "blox-relabeled-watersheds-on-resized-gradient-image.png"))

(saveimage (car img3)  (build-path vigraplt-path "rect-fft-real.png"))
(saveimage (cdr img3)  (build-path vigraplt-path "rect-fft-imag.png"))

(saveimage img3magnitude (build-path vigraplt-path "rect-fft-magnitude.png"))
(saveimage (image-map sqrt img3magnitude) (build-path vigraplt-path "rect-fft-sqrt-magnitude.png"))

(saveimage img4   (build-path vigraplt-path "blox-reflected-both.png"))
(saveimage img5   (build-path vigraplt-path "blox-rotated-15deg.png"))
(saveimage img6   (build-path vigraplt-path "blox-aff-rotated-15deg.png"))
(saveimage img7   (build-path vigraplt-path "blox-disttransform-on-canny.png"))
(saveimage img8   (build-path vigraplt-path "blox-diff_of_exp.png"))
(saveimage img9   (build-path vigraplt-path "blox-gsmooth-3.0.png"))
(saveimage img10  (build-path vigraplt-path "blox-log-3.0.png"))
(saveimage img11  (build-path vigraplt-path "blox-gsharpening-0.5-3.0.png"))
(saveimage img12  (build-path vigraplt-path "blox-sharpening-3.0.png"))
(saveimage img13  (build-path vigraplt-path "blox-nonlineardiffusion-0.1-2.0.png"))

(show-image img5)
(show-image img6 "title: img6")