#include "vigra/impex.hxx"
#include "os_settings.hxx"

LIBEXPORT int vigra_importimage_c(float *arr, int width, int height, const char * filename){ 
    try
    {
        // read image given as first argument
        // file type is determined automatically
      vigra::ImageImportInfo info(filename);
      if( info.width() == width && info.height() == height)
	if( info.isGrayscale() && info.width() == width && info.height() == height)
        {
            // create a gray scale image of appropriate size
	    vigra::BasicImageView<float> in(arr, info.width(), info.height());
            
            // import the image just read
            importImage(info, destImage(in));
        }
        else
        {
	  return 2;
        }
      else
	return 3;
    }
    catch (vigra::StdException & e)
    {
        return 1;
    }
    return 0;
}
LIBEXPORT int vigra_exportimage_c(const float *arr, int width, int height, const char * filename){ 
    try
    {
        // read image given as first argument
        // file type is determined automatically
      vigra::ImageExportInfo info(filename);
      
      // create a gray scale image of appropriate size
      vigra::BasicImageView<float> out(arr, width, height);
            
            // import the image just read
      vigra::exportImage(srcImageRange(out), info);
    }
    catch (vigra::StdException & e)
    {
        return 1;
    }
    return 0;
}
LIBEXPORT int get_width_c(const char * filename){ 
    try
    {
        // read image given as first argument
        // file type is determined automatically
      vigra::ImageImportInfo info(filename);
      return info.width();
    }
    catch (vigra::StdException & e)
    {
        return 0;
    }
}
LIBEXPORT int get_height_c(const char * filename){ 
    try
    {
        // read image given as first argument
        // file type is determined automatically
      vigra::ImageImportInfo info(filename);
      return info.height();
    }
    catch (vigra::StdException & e)
    {
        return 0;
    }
}
	
LIBEXPORT int get_numBands_c(const char * filename){ 
    try
    {
        // read image given as first argument
        // file type is determined automatically
      vigra::ImageImportInfo info(filename);
      return info.numBands();
    }
    catch (vigra::StdException & e)
    {
        return 0;
    }
}
