;###############################################################################
;###################         Resize image                   ####################

(define vigra_resizeimage_c
  (get-ffi-obj 'vigra_resizeimage_c dylib-path
               (_fun (img_vector1 img_vector2  width height width2 height2 resize_mode) :: [img_vector1 : _cvector]
                     [img_vector2 : _cvector]
                     [width : _int]
                     [height : _int]
                     [width2 : _int]
                     [height2 : _int]
                     [resize_mode : _int]
                     -> (res :  _int))))

(define (resizeimage image width2 height2 resize_mode)
  (let* ((width  (image-width  image))
	 (height (image-height image))
	 (img2   (make-image width2 height2 0.0))
	 (foo    (vigra_resizeimage_c (image-data image) (image-data img2) width height width2 height2 resize_mode)))
    (case foo
      ((0) img2)
      ((1) (error "Error in vigraplt.imgproc:resizeimage: Resize of image failed!!"))
      ((2) (error "Error in vigraplt.imgproc:resizeimage: Resize mode must be in {0,1,2,3,4}!!")))))


;###############################################################################
;###################         Rotate image                   ####################

(define vigra_rotateimage_c
  (get-ffi-obj 'vigra_rotateimage_c dylib-path
               (_fun (img_vector1 img_vector2  width height angle resize_mode) :: [img_vector1 : _cvector]
                     [img_vector2 : _cvector]
                     [width : _int]
                     [height : _int]
                     [angle : _float]
                     [resize_mode : _int]
                     -> (res :  _int))))

(define (rotateimage image angle resize_mode)
  (let* ((width  (image-width  image))
	 (height (image-height image))
	 (img2 (make-image width height 0.0))
	 (foo   (vigra_rotateimage_c  (image-data image) (image-data img2) width height angle resize_mode)))
    (case foo
      ((0) img2)
      ((1) (error "Error in vigraplt.imgproc:rotateimage: Rotation of image failed!!"))
      ((2) (error "Error in vigraplt.imgproc:rotateimage: Resize mode must be in {0,1,2,3,4}!!")))))

;###############################################################################
;###################         Affine transform image         ####################

(define vigra_affinewarpimage_c
  (get-ffi-obj 'vigra_affinewarpimage_c dylib-path
               (_fun (img_vector1 img_vector2  affineMat width height resize_mode) :: [img_vector1 : _cvector]
                     [img_vector2 : _cvector]
                     [affineMat   : _cvector]
                     [width : _int]
                     [height : _int]
                     [resize_mode : _int]
                     -> (res :  _int))))

(define (affinewarpimage image affinematrix resize_mode)
  (let* ((width  (image-width  image))
	 (height (image-height image))
         (img2   (make-image width height 0.0))
	 (foo    (vigra_affinewarpimage_c (image-data image) (image-data img2) (matrix-data affinematrix) width height resize_mode)))
    (case foo
      ((0) img2)
      ((1) (error "Error in vigraplt.imgproc:affinewarpimage: Affine Warp of image failed!!"))
      ((2) (error "Error in vigraplt.imgproc:affinewarpimage: Resize mode must be in {0,1,2,3,4}!!")))))


;###############################################################################
;###################         Reflect image                  ####################

(define vigra_reflectimage_c
  (get-ffi-obj 'vigra_reflectimage_c dylib-path
               (_fun (img_vector1 img_vector2  width height reflect_mode) :: [img_vector1 : _cvector]
                     [img_vector2 : _cvector]
                     [width : _int]
                     [height : _int]
                     [reflect_mode : _int]
                     -> (res :  _int))))

(define (reflectimage image reflect_mode)
  (let* ((width  (image-width  image))
	 (height (image-height image))
	 (img2   (make-image width height 0.0))
	 (foo    (vigra_reflectimage_c (image-data image) (image-data img2) width height reflect_mode)))
    (case foo
      ((0) img2)
      ((1) (error "Error in vigraplt.imgproc:reflectimage: Reflection of image failed!!"))
      ((2) (error "Error in vigraplt.imgproc:reflectimage: Reflection mode must be in {1 (= horizontal), 2 (= vertical), 3 (=both)}!!")))))
	  
	  

;###############################################################################
;###################         Fast Fourier Transform         ####################

(define vigra_fouriertransform_c
  (get-ffi-obj 'vigra_fouriertransform_c dylib-path
               (_fun (img_vector1 img_vector2   img_vector3  width height) :: [img_vector1 : _cvector]
                     [img_vector2 : _cvector]
                     [img_vector3 : _cvector]
                     [width : _int]
                     [height : _int]
                     -> (res :  _int))))

(define (fouriertransform image)
  (let* ((width  (image-width  image))
	 (height (image-height image))
	 (img2 (make-image width height 0.0))
	 (img3 (make-image width height 0.0))
	 (foo   (vigra_fouriertransform_c (image-data image) (image-data img2) (image-data img3) width height)))
    (case foo
      ((0) (cons img2 img3))
      ((1) (error "Error in vigraplt.imgproc:fouriertransform: FastFourier Transform of image failed!!")))))